==> nextcloud-app-calendar-1:5.5.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/ia.js <==
OC.L10N.register(
    "calendar",
    {
    "Hello," : "Salute %s,",
    "Cheers!" : "Congratulationes!",
    "Calendar" : "Calendario",
    "Confirm" : "Confirmar",
    "Today" : "Hodie",
    "Day" : "Die",
    "Week" : "Septimana",
    "Month" : "Mense",
    "Preview" : "Previsualisar",
    "Copy link" : "Copiar ligamine",
    "Edit" : "Modificar",
    "Delete" : "Deler",
    "New calendar" : "Nove calendario",
    "Export" : "Exportar",
    "Name" : "Nomine",
    "Deleted" : "Delite",
    "Restore" : "Restaurar",
    "Delete permanently" : "Deler permanentemente",
    "Hidden" : "Occultate",
    "Share link" : "Compartir ligamine",
    "can edit" : "pote modificar",
    "Share with users or groups" : "Compartir con usatores o gruppos",
    "Save" : "Salveguardar",
    "View" : "Vider",
    "Cancel" : "Cancellar",
    "Automatic" : "Automatic",
    "Actions" : "Actiones",
    "General" : "General",
    "Show week numbers" : "Monstrar le numero del septimanas",
    "Keyboard shortcuts" : "Combinationes de claves",
    "Update" : "Actualisar",
    "Location" : "Loco",
    "Description" : "Description",
    "to" : "a",
    "Add" : "Adder",
    "Monday" : "Lunedi",
    "Tuesday" : "Martedi",
    "Wednesday" : "Mercuridi",
    "Thursday" : "Jovedi",
    "Friday" : "Venerdi",
    "Saturday" : "Sabbato",
    "Sunday" : "Dominica",
    "Your email address" : "Tu adresse de e-posta",
    "Email" : "E-posta",
    "seconds" : "secundas",
    "minutes" : "minutas",
    "hours" : "horas",
    "days" : "dies",
    "weeks" : "septimanas",
    "Choose a file to add as attachment" : "Selectiona un file pro adder como attachamento",
    "Done" : "Preste",
    "Unknown" : "Incognite",
    "Accept" : "Acceptar",
    "Decline" : "Refusar",
    "Tentative" : "Tentative",
    "Attendees" : "Participantes",
    "Repeat" : "Repeter",
    "never" : "nunquam",
    "after" : "post",
    "Global" : "Global",
    "Subscribe" : "Subscribe",
    "Personal" : "Personal",
    "Edit event" : "Modificar evento",
    "Close" : "Clauder",
    "Anniversary" : "Anniversario de evento",
    "Week {number} of {year}" : "Septimana {number} de {year}",
    "Daily" : "Cata die",
    "Weekly" : "Cata septimana",
    "second" : "secunda",
    "Other" : "Altere",
    "When shared show full event" : "Quando compartite, monstrar evento integremente",
    "When shared show only busy" : "Quando compartite, monstrar solo si illo es occupate",
    "When shared hide this event" : "Quando compartite, celar iste evento",
    "Confirmed" : "Confirmate"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1:6.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/ia.js <==
OC.L10N.register(
    "calendar",
    {
    "Hello," : "Salute %s,",
    "Cheers!" : "Congratulationes!",
    "Calendar" : "Calendario",
    "Confirm" : "Confirmar",
    "Today" : "Hodie",
    "Day" : "Die",
    "Week" : "Septimana",
    "Month" : "Mense",
    "Preview" : "Previsualisar",
    "Copy link" : "Copiar ligamine",
    "Edit" : "Modificar",
    "Delete" : "Deler",
    "New calendar" : "Nove calendario",
    "Export" : "Exportar",
    "Name" : "Nomine",
    "Deleted" : "Delite",
    "Restore" : "Restaurar",
    "Delete permanently" : "Deler permanentemente",
    "Share link" : "Compartir ligamine",
    "can edit" : "pote modificar",
    "Share with users or groups" : "Compartir con usatores o gruppos",
    "Save" : "Salveguardar",
    "View" : "Vider",
    "Cancel" : "Cancellar",
    "Automatic" : "Automatic",
    "Actions" : "Actiones",
    "General" : "General",
    "Show week numbers" : "Monstrar le numero del septimanas",
    "Keyboard shortcuts" : "Combinationes de claves",
    "Update" : "Actualisar",
    "Location" : "Loco",
    "Description" : "Description",
    "to" : "a",
    "Add" : "Adder",
    "Monday" : "Lunedi",
    "Tuesday" : "Martedi",
    "Wednesday" : "Mercuridi",
    "Thursday" : "Jovedi",
    "Friday" : "Venerdi",
    "Saturday" : "Sabbato",
    "Sunday" : "Dominica",
    "Your email address" : "Tu adresse de e-posta",
    "Email" : "E-posta",
    "seconds" : "secundas",
    "minutes" : "minutas",
    "hours" : "horas",
    "days" : "dies",
    "weeks" : "septimanas",
    "Choose a file to add as attachment" : "Selectiona un file pro adder como attachamento",
    "Done" : "Preste",
    "Unknown" : "Incognite",
    "Accept" : "Acceptar",
    "Decline" : "Refusar",
    "Tentative" : "Tentative",
    "Attendees" : "Participantes",
    "Repeat" : "Repeter",
    "never" : "nunquam",
    "after" : "post",
    "None" : "Nulle",
    "Global" : "Global",
    "Subscribe" : "Subscribe",
    "Personal" : "Personal",
    "Edit event" : "Modificar evento",
    "Close" : "Clauder",
    "Anniversary" : "Anniversario de evento",
    "Week {number} of {year}" : "Septimana {number} de {year}",
    "Daily" : "Cata die",
    "Weekly" : "Cata septimana",
    "second" : "secunda",
    "Other" : "Altere",
    "When shared show full event" : "Quando compartite, monstrar evento integremente",
    "When shared show only busy" : "Quando compartite, monstrar solo si illo es occupate",
    "When shared hide this event" : "Quando compartite, celar iste evento",
    "Confirmed" : "Confirmate",
    "Hidden" : "Occultate"
},
"nplurals=2; plural=(n != 1);");
